@@ -8,7 +8,7 @@ using namespace MIPSReflection;
 void CMA_MIPSIV::ReflOpTarget(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
 {
 	nAddress = (nAddress & 0xF0000000) | ((nOpcode & 0x03FFFFFF) << 2);
-	sprintf(sText, "$%08X", nAddress);
+	snprintf(sText, nCount, "$%08X", nAddress);
 }
 
 void CMA_MIPSIV::ReflOpRtRsImm(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
@@ -17,7 +17,7 @@ void CMA_MIPSIV::ReflOpRtRsImm(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress
 	uint8 nRT = (uint8)((nOpcode >> 16) & 0x001F);
 	uint16 nImm = (uint16)((nOpcode >> 0) & 0xFFFF);
 
-	sprintf(sText, "%s, %s, $%04X", CMIPS::m_sGPRName[nRT], CMIPS::m_sGPRName[nRS], nImm);
+	snprintf(sText, nCount, "%s, %s, $%04X", CMIPS::m_sGPRName[nRT], CMIPS::m_sGPRName[nRS], nImm);
 }
 
 void CMA_MIPSIV::ReflOpRsImm(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
@@ -25,7 +25,7 @@ void CMA_MIPSIV::ReflOpRsImm(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress,
 	uint8 nRS = (uint8)((nOpcode >> 21) & 0x001F);
 	uint16 nImm = (uint16)((nOpcode >> 0) & 0xFFFF);
 
-	sprintf(sText, "%s, $%04X", CMIPS::m_sGPRName[nRS], nImm);
+	snprintf(sText, nCount, "%s, $%04X", CMIPS::m_sGPRName[nRS], nImm);
 }
 
 void CMA_MIPSIV::ReflOpRtImm(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
@@ -33,7 +33,7 @@ void CMA_MIPSIV::ReflOpRtImm(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress,
 	uint8 nRT = (uint8)((nOpcode >> 16) & 0x001F);
 	uint16 nImm = (uint16)((nOpcode >> 0) & 0xFFFF);
 
-	sprintf(sText, "%s, $%04X", CMIPS::m_sGPRName[nRT], nImm);
+	snprintf(sText, nCount, "%s, $%04X", CMIPS::m_sGPRName[nRT], nImm);
 }
 
 void CMA_MIPSIV::ReflOpRsRtOff(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
@@ -43,7 +43,7 @@ void CMA_MIPSIV::ReflOpRsRtOff(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress
 	uint16 nImm = (uint16)((nOpcode >> 0) & 0xFFFF);
 
 	nAddress += 4;
-	sprintf(sText, "%s, %s, $%08X", CMIPS::m_sGPRName[nRS], CMIPS::m_sGPRName[nRT], (nAddress + CMIPS::GetBranch(nImm)));
+	snprintf(sText, nCount, "%s, %s, $%08X", CMIPS::m_sGPRName[nRS], CMIPS::m_sGPRName[nRT], (nAddress + CMIPS::GetBranch(nImm)));
 }
 
 void CMA_MIPSIV::ReflOpRsOff(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
@@ -52,7 +52,7 @@ void CMA_MIPSIV::ReflOpRsOff(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress,
 	uint16 nImm = (uint16)((nOpcode >> 0) & 0xFFFF);
 
 	nAddress += 4;
-	sprintf(sText, "%s, $%08X", CMIPS::m_sGPRName[nRS], (nAddress + CMIPS::GetBranch(nImm)));
+	snprintf(sText, nCount, "%s, $%08X", CMIPS::m_sGPRName[nRS], (nAddress + CMIPS::GetBranch(nImm)));
 }
 
 void CMA_MIPSIV::ReflOpRtOffRs(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
@@ -62,7 +62,7 @@ void CMA_MIPSIV::ReflOpRtOffRs(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress
 	uint16 nImm = (uint16)((nOpcode >> 0) & 0xFFFF);
 
 	nAddress += 4;
-	sprintf(sText, "%s, $%04X(%s)", CMIPS::m_sGPRName[nRT], nImm, CMIPS::m_sGPRName[nRS]);
+	snprintf(sText, nCount, "%s, $%04X(%s)", CMIPS::m_sGPRName[nRT], nImm, CMIPS::m_sGPRName[nRS]);
 }
 
 void CMA_MIPSIV::ReflOpHintOffRs(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
@@ -72,7 +72,7 @@ void CMA_MIPSIV::ReflOpHintOffRs(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddre
 	uint16 nImm = (uint16)((nOpcode >> 0) & 0xFFFF);
 
 	nAddress += 4;
-	sprintf(sText, "%i, $%04X(%s)", nHint, nImm, CMIPS::m_sGPRName[nRS]);
+	snprintf(sText, nCount, "%d, $%04X(%s)", nHint, nImm, CMIPS::m_sGPRName[nRS]);
 }
 
 void CMA_MIPSIV::ReflOpIdOffRs(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
@@ -82,7 +82,7 @@ void CMA_MIPSIV::ReflOpIdOffRs(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress
 	uint16 nImm = (uint16)((nOpcode >> 0) & 0xFFFF);
 
 	nAddress += 4;
-	sprintf(sText, "$%02X, $%04X(%s)", nRT, nImm, CMIPS::m_sGPRName[nRS]);
+	snprintf(sText, nCount, "$%02X, $%04X(%s)", nRT, nImm, CMIPS::m_sGPRName[nRS]);
 }
 
 void CMA_MIPSIV::ReflOpRdRsRt(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
@@ -91,7 +91,7 @@ void CMA_MIPSIV::ReflOpRdRsRt(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress,
 	uint8 nRT = (uint8)((nOpcode >> 16) & 0x001F);
 	uint8 nRD = (uint8)((nOpcode >> 11) & 0x001F);
 
-	sprintf(sText, "%s, %s, %s", CMIPS::m_sGPRName[nRD], CMIPS::m_sGPRName[nRS], CMIPS::m_sGPRName[nRT]);
+	snprintf(sText, nCount, "%s, %s, %s", CMIPS::m_sGPRName[nRD], CMIPS::m_sGPRName[nRS], CMIPS::m_sGPRName[nRT]);
 }
 
 void CMA_MIPSIV::ReflOpRdRtSa(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
@@ -100,7 +100,7 @@ void CMA_MIPSIV::ReflOpRdRtSa(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress,
 	uint8 nRD = (uint8)((nOpcode >> 11) & 0x001F);
 	uint8 nSA = (uint8)((nOpcode >> 6) & 0x001F);
 
-	sprintf(sText, "%s, %s, %i", CMIPS::m_sGPRName[nRD], CMIPS::m_sGPRName[nRT], nSA);
+	snprintf(sText, nCount, "%s, %s, %d", CMIPS::m_sGPRName[nRD], CMIPS::m_sGPRName[nRT], nSA);
 }
 
 void CMA_MIPSIV::ReflOpRdRtRs(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
@@ -109,21 +109,21 @@ void CMA_MIPSIV::ReflOpRdRtRs(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress,
 	uint8 nRT = (uint8)((nOpcode >> 16) & 0x001F);
 	uint8 nRD = (uint8)((nOpcode >> 11) & 0x001F);
 
-	sprintf(sText, "%s, %s, %s", CMIPS::m_sGPRName[nRD], CMIPS::m_sGPRName[nRT], CMIPS::m_sGPRName[nRS]);
+	snprintf(sText, nCount, "%s, %s, %s", CMIPS::m_sGPRName[nRD], CMIPS::m_sGPRName[nRT], CMIPS::m_sGPRName[nRS]);
 }
 
 void CMA_MIPSIV::ReflOpRs(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
 {
 	uint8 nRS = (uint8)((nOpcode >> 21) & 0x001F);
 
-	sprintf(sText, "%s", CMIPS::m_sGPRName[nRS]);
+	snprintf(sText, nCount, "%s", CMIPS::m_sGPRName[nRS]);
 }
 
 void CMA_MIPSIV::ReflOpRd(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
 {
 	uint8 nRD = (uint8)((nOpcode >> 11) & 0x001F);
 
-	sprintf(sText, "%s", CMIPS::m_sGPRName[nRD]);
+	snprintf(sText, nCount, "%s", CMIPS::m_sGPRName[nRD]);
 }
 
 void CMA_MIPSIV::ReflOpRdRs(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
@@ -131,7 +131,7 @@ void CMA_MIPSIV::ReflOpRdRs(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, u
 	uint8 nRS = (uint8)((nOpcode >> 21) & 0x001F);
 	uint8 nRD = (uint8)((nOpcode >> 11) & 0x001F);
 
-	sprintf(sText, "%s, %s", CMIPS::m_sGPRName[nRD], CMIPS::m_sGPRName[nRS]);
+	snprintf(sText, nCount, "%s, %s", CMIPS::m_sGPRName[nRD], CMIPS::m_sGPRName[nRS]);
 }
 
 void CMA_MIPSIV::ReflOpRsRt(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode, char* sText, unsigned int nCount)
@@ -139,7 +139,7 @@ void CMA_MIPSIV::ReflOpRsRt(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, u
 	uint8 nRS = (uint8)((nOpcode >> 21) & 0x001F);
 	uint8 nRT = (uint8)((nOpcode >> 16) & 0x001F);
 
-	sprintf(sText, "%s, %s", CMIPS::m_sGPRName[nRS], CMIPS::m_sGPRName[nRT]);
+	snprintf(sText, nCount, "%s, %s", CMIPS::m_sGPRName[nRS], CMIPS::m_sGPRName[nRT]);
 }
 
 uint32 CMA_MIPSIV::ReflEaTarget(INSTRUCTION* pInstr, CMIPS* pCtx, uint32 nAddress, uint32 nOpcode)
