@@ -12,6 +12,7 @@
 #include "ee/EeExecutor.h"
 #include "Ps2Const.h"
 #include "iop/Iop_SifManPs2.h"
+#include "iop/UsbBuzzerDevice.h"
 #include "StdStream.h"
 #include "StdStreamUtils.h"
 #include "states/MemoryStateFile.h"
@@ -183,8 +184,23 @@ void CPS2VM::DestroyPadHandler()
 
 void CPS2VM::CreateSoundHandler(const CSoundHandler::FactoryFunction& factoryFunction)
 {
-	if(m_soundHandler != nullptr) return;
-	m_mailBox.SendCall([this, factoryFunction]() { CreateSoundHandlerImpl(factoryFunction); }, true);
+	if(m_soundHandler) return;
+	std::exception_ptr exception;
+	m_mailBox.SendCall([this, factoryFunction, &exception]() {
+		try
+		{
+			CreateSoundHandlerImpl(factoryFunction);
+		}
+		catch(...)
+		{
+			exception = std::current_exception();
+		}
+	},
+	                   true);
+	if(exception)
+	{
+		std::rethrow_exception(exception);
+	}
 }
 
 CSoundHandler* CPS2VM::GetSoundHandler()
@@ -837,6 +853,11 @@ void CPS2VM::RegisterModulesInPadHandler()
 	m_pad->RemoveAllListeners();
 	m_pad->InsertListener(iopOs->GetPadman());
 	m_pad->InsertListener(&m_iop->m_sio2);
+
+	{
+		auto device = iopOs->GetUsbd()->GetDevice<Iop::CBuzzerUsbDevice>();
+		device->SetPadHandler(m_pad);
+	}
 }
 
 void CPS2VM::ReloadExecutable(const char* executablePath, const CPS2OS::ArgumentList& arguments)
@@ -902,10 +923,10 @@ void CPS2VM::EmuThread()
 			{
 				if(m_hblankTicks <= 0)
 				{
+					m_hblankTicks += m_hblankTicksTotal;
 					if(m_ee->m_gs)
 					{
 						m_ee->m_gs->SetHBlank();
-						m_hblankTicks += m_hblankTicksTotal;
 					}
 				}
 
