@@ -1,5 +1,4 @@
-#ifndef _PADHANDLER_H_
-#define _PADHANDLER_H_
+#pragma once
 
 #include "PadInterface.h"
 #include <list>
@@ -14,11 +13,10 @@ public:
 	virtual ~CPadHandler() = default;
 	virtual void Update(uint8*) = 0;
 	void InsertListener(CPadInterface*);
+	bool HasListener(CPadInterface*) const;
 	void RemoveAllListeners();
 
 protected:
 	typedef std::list<CPadInterface*> ListenerList;
 	ListenerList m_interfaces;
 };
-
-#endif
