@@ -1,7 +1,7 @@
 #include <assert.h>
 #include "COP_VU.h"
 #include "VUShared.h"
-#include "../Log.h"
+#include "Log.h"
 #include "../MIPS.h"
 #include "../MemoryUtils.h"
 #include "offsetof_def.h"
@@ -283,24 +283,28 @@ void CCOP_VU::CTC2()
 			m_codeGen->PullRel(offsetof(CMIPS, m_State.cmsar0));
 			break;
 		case CTRL_REG_FBRST:
-			//Don't care
+		{
+			uint32 valueCursor = m_codeGen->GetTopCursor();
+
+			m_codeGen->PushCtx();
+			m_codeGen->PushCursor(valueCursor);
+			m_codeGen->PushCst(CVpu::EE_ADDR_VU_FBRST);
+			m_codeGen->Call(reinterpret_cast<void*>(&MemoryUtils_SetWordProxy), 3, Jitter::CJitter::RETURN_VALUE_NONE);
+
 			m_codeGen->PullTop();
-			break;
+		}
+		break;
 		case CTRL_REG_CMSAR1:
 		{
 			m_codeGen->PushCst(0xFFFF);
 			m_codeGen->And();
 			uint32 valueCursor = m_codeGen->GetTopCursor();
 
-			//Push context
 			m_codeGen->PushCtx();
-			//Push value
 			m_codeGen->PushCursor(valueCursor);
-			//Compute Address
 			m_codeGen->PushCst(CVpu::EE_ADDR_VU_CMSAR1);
 			m_codeGen->Call(reinterpret_cast<void*>(&MemoryUtils_SetWordProxy), 3, Jitter::CJitter::RETURN_VALUE_NONE);
-			//Clear stack
-			assert(m_codeGen->GetTopCursor() == valueCursor);
+
 			m_codeGen->PullTop();
 		}
 		break;
@@ -573,7 +577,7 @@ void CCOP_VU::VCALLMS()
 	m_codeGen->PushCst(static_cast<uint32>(m_nImm15) * 8);
 	m_codeGen->PullRel(offsetof(CMIPS, m_State.callMsAddr));
 
-	m_codeGen->PushCst(MIPS_EXCEPTION_CALLMS);
+	m_codeGen->PushCst(MIPS_EXCEPTION_VU_CALLMS);
 	m_codeGen->PullRel(offsetof(CMIPS, m_State.nHasException));
 }
 
@@ -587,7 +591,7 @@ void CCOP_VU::VCALLMSR()
 	m_codeGen->Shl(3);
 	m_codeGen->PullRel(offsetof(CMIPS, m_State.callMsAddr));
 
-	m_codeGen->PushCst(MIPS_EXCEPTION_CALLMS);
+	m_codeGen->PushCst(MIPS_EXCEPTION_VU_CALLMS);
 	m_codeGen->PullRel(offsetof(CMIPS, m_State.nHasException));
 }
 
@@ -698,7 +702,7 @@ void CCOP_VU::VMOVE()
 //0D
 void CCOP_VU::VLQI()
 {
-	VUShared::LQI(m_codeGen, m_nDest, m_nIT, m_nIS, m_vuMemAddressMask);
+	VUShared::LQI(m_codeGen, m_nDest, m_nIT, m_nIS, m_vuMemAddressMask, &CCOP_VU::EmitVu1AreaReadHandler);
 }
 
 //0E
@@ -936,6 +940,29 @@ void CCOP_VU::VRXOR()
 //Helpers
 //////////////////////////////////////////////////
 
+void CCOP_VU::EmitVu1AreaReadHandler(CMipsJitter* codeGen, uint8 is, uint8 it)
+{
+	codeGen->PushRel(offsetof(CMIPS, m_State.nCOP2VI[is]));
+	codeGen->Shl(4);
+	codeGen->PushCst(CVpu::VU_ADDR_VU1AREA_START);
+	codeGen->Sub();
+	codeGen->PushCst(CVpu::EE_ADDR_VU1AREA_START);
+	codeGen->Add();
+
+	for(unsigned int i = 0; i < 4; i++)
+	{
+		codeGen->PushCtx();
+		codeGen->PushIdx(1);
+		codeGen->Call(reinterpret_cast<void*>(&MemoryUtils_GetWordProxy), 2, Jitter::CJitter::RETURN_VALUE_32);
+		codeGen->PullRel(offsetof(CMIPS, m_State.nCOP2[it].nV[i]));
+
+		codeGen->PushCst(4);
+		codeGen->Add();
+	}
+
+	codeGen->PullTop();
+}
+
 void CCOP_VU::EmitVu1AreaWriteHandler(CMipsJitter* codeGen, uint8 is, uint8 it)
 {
 	codeGen->PushRel(offsetof(CMIPS, m_State.nCOP2VI[it]));
