@@ -2,9 +2,11 @@
 #include <cassert>
 #include <cstring>
 #include <stdio.h>
+#include <algorithm>
 #include <exception>
 #include <functional>
 #include "maybe_unused.h"
+#include "EndianUtils.h"
 #include "IPU_MacroblockAddressIncrementTable.h"
 #include "IPU_MacroblockTypeITable.h"
 #include "IPU_MacroblockTypePTable.h"
@@ -20,7 +22,7 @@
 #include "mpeg2/InverseScanTable.h"
 #include "idct/TrivialC.h"
 #include "idct/IEEE1180.h"
-#include "../Log.h"
+#include "Log.h"
 #include "DMAC.h"
 #include "INTC.h"
 #include "Ps2Const.h"
@@ -140,8 +142,8 @@ void CIPU::Reset()
 
 uint32 CIPU::GetRegister(uint32 nAddress)
 {
-#ifdef _DEBUG
-//	DisassembleGet(nAddress);
+#if LOGGING_ENABLED
+	DisassembleGet(nAddress);
 #endif
 
 	switch(nAddress)
@@ -231,7 +233,7 @@ uint32 CIPU::GetRegister(uint32 nAddress)
 
 void CIPU::SetRegister(uint32 nAddress, uint32 nValue)
 {
-#ifdef _DEBUG
+#if LOGGING_ENABLED
 	DisassembleSet(nAddress, nValue);
 #endif
 
@@ -252,7 +254,7 @@ void CIPU::SetRegister(uint32 nAddress, uint32 nValue)
 			InitializeCommand(nValue);
 			m_isBusy = true;
 		}
-#ifdef _DEBUG
+#if LOGGING_ENABLED
 		DisassembleCommand(nValue);
 #endif
 		break;
@@ -997,12 +999,7 @@ void CIPU::CINFIFO::LoadState(const char* regsFileName, Framework::CZipArchiveRe
 void CIPU::CINFIFO::SyncLookupBits()
 {
 	unsigned int lookupPosition = (m_bitPosition & ~0x1F) / 8;
-	uint8 lookupBytes[8];
-	for(unsigned int i = 0; i < 8; i++)
-	{
-		lookupBytes[7 - i] = m_buffer[lookupPosition + i];
-	}
-	m_lookupBits = *reinterpret_cast<uint64*>(lookupBytes);
+	m_lookupBits = Framework::CEndian::FromMSBF64(*reinterpret_cast<const uint64*>(m_buffer + lookupPosition));
 }
 
 /////////////////////////////////////////////
@@ -1262,17 +1259,19 @@ bool CIPU::CIDECCommand::IsDelayed() const
 void CIPU::CIDECCommand::ConvertRawBlock()
 {
 	//Convert block from RAW16 to RAW8
-	int16 blockData[CCSCCommand::BLOCK_SIZE];
+	int16 inBlockData[CCSCCommand::BLOCK_SIZE];
+	uint8 outBlockData[CCSCCommand::BLOCK_SIZE];
 	m_blockStream.Seek(0, Framework::STREAM_SEEK_SET);
-	m_blockStream.Read(blockData, CCSCCommand::BLOCK_SIZE * sizeof(int16));
-	m_blockStream.ResetBuffer();
+	m_blockStream.Read(inBlockData, CCSCCommand::BLOCK_SIZE * sizeof(int16));
 	for(uint32 i = 0; i < CCSCCommand::BLOCK_SIZE; i++)
 	{
-		int16 blockValue = blockData[i];
+		int16 blockValue = inBlockData[i];
 		blockValue = std::max<int16>(blockValue, 0);
 		blockValue = std::min<int16>(blockValue, 255);
-		m_blockStream.Write8(static_cast<uint8>(blockValue));
+		outBlockData[i] = static_cast<uint8>(blockValue);
 	}
+	m_blockStream.ResetBuffer();
+	m_blockStream.Write(outBlockData, CCSCCommand::BLOCK_SIZE * sizeof(uint8));
 }
 
 /////////////////////////////////////////////
