@@ -5,6 +5,11 @@
 class CMA_EE : public CMA_MIPSIV
 {
 public:
+	enum COMPILEHINT
+	{
+		COMPILEHINT_FPU_USE_ACCURATE_ADD_SUB = (1 << 0),
+	};
+
 	CMA_EE();
 	virtual ~CMA_EE() = default;
 
@@ -101,6 +106,7 @@ private:
 	void PEXTLH();
 	void PPACH();
 	void PADDSB();
+	void PSUBSB();
 	void PEXTLB();
 	void PPACB();
 	void PEXT5();
