@@ -3,7 +3,7 @@
 #include <stdexcept>
 #include "static_loop.h"
 #include "string_format.h"
-#include "../Log.h"
+#include "Log.h"
 #include "../Ps2Const.h"
 #include "../states/RegisterStateFile.h"
 #include "../states/MemoryStateFile.h"
@@ -102,7 +102,7 @@ uint32 CVif::GetRegister(uint32 address)
 			//Some games will keep reading this register in a loop to verify the state of the VEW bit.
 			//- Red Faction
 			//- RPG Maker 3
-			if(!m_vpu.IsVuRunning())
+			if(m_vpu.IsVuReady())
 			{
 				m_STAT.nVEW = 0;
 			}
@@ -181,7 +181,7 @@ uint32 CVif::GetRegister(uint32 address)
 		CLog::GetInstance().Warn(LOG_NAME, "Reading unknown register 0x%08X.\r\n", address);
 		break;
 	}
-#ifdef _DEBUG
+#if LOGGING_ENABLED
 	DisassembleGet(address);
 #endif
 	return result;
@@ -245,7 +245,7 @@ void CVif::SetRegister(uint32 address, uint32 value)
 			break;
 		}
 	}
-#ifdef _DEBUG
+#if LOGGING_ENABLED
 	DisassembleSet(address, value);
 #endif
 }
@@ -353,7 +353,7 @@ uint32 CVif::GetITOP() const
 
 uint32 CVif::ReceiveDMA(uint32 address, uint32 qwc, uint32 unused, bool tagIncluded)
 {
-	if(m_STAT.nVEW && m_vpu.IsVuRunning())
+	if(m_STAT.nVEW && !m_vpu.IsVuReady())
 	{
 		//Is waiting for program end, don't bother
 		return 0;
@@ -363,7 +363,7 @@ uint32 CVif::ReceiveDMA(uint32 address, uint32 qwc, uint32 unused, bool tagInclu
 	CProfilerZone profilerZone(m_vifProfilerZone);
 #endif
 
-#ifdef _DEBUG
+#if LOGGING_ENABLED
 	CLog::GetInstance().Print(LOG_NAME, "vif%i : Processing packet @ 0x%08X, qwc = 0x%X, tagIncluded = %i\r\n",
 	                          m_number, address, qwc, static_cast<int>(tagIncluded));
 #endif
@@ -426,7 +426,7 @@ void CVif::ProcessPacket(StreamType& stream)
 		}
 		if(m_STAT.nVEW == 1)
 		{
-			if(m_vpu.IsVuRunning()) break;
+			if(!m_vpu.IsVuReady()) break;
 			m_STAT.nVEW = 0;
 			//Command is waiting for micro-program to end.
 			ExecuteCommand(stream, m_CODE);
@@ -438,7 +438,7 @@ void CVif::ProcessPacket(StreamType& stream)
 			break;
 		}
 
-		stream.Read(&m_CODE, sizeof(CODE));
+		stream.ReadValue<4>(&m_CODE);
 
 		if(m_CODE.nI != 0)
 		{
@@ -476,7 +476,7 @@ void CVif::ProcessPacket(StreamType& stream)
 
 void CVif::ExecuteCommand(StreamType& stream, CODE nCommand)
 {
-#ifdef _DEBUG
+#if LOGGING_ENABLED
 	if(m_number == 0)
 	{
 		DisassembleCommand(nCommand);
@@ -510,7 +510,7 @@ void CVif::ExecuteCommand(StreamType& stream, CODE nCommand)
 		m_STAT.nMRK = 1;
 		break;
 	case CODE_CMD_FLUSHE:
-		if(m_vpu.IsVuRunning())
+		if(!m_vpu.IsVuReady())
 		{
 			m_STAT.nVEW = 1;
 		}
@@ -585,7 +585,7 @@ void CVif::Cmd_MPG(StreamType& stream, CODE nCommand)
 	nDstAddr &= (m_vpu.GetMicroMemorySize() - 1);
 
 	//Check if microprogram is running
-	if(m_vpu.IsVuRunning())
+	if(!m_vpu.IsVuReady())
 	{
 		m_STAT.nVEW = 1;
 		return;
@@ -643,7 +643,7 @@ void CVif::Cmd_STROW(StreamType& stream, CODE nCommand)
 	while(m_NUM != 0 && stream.GetAvailableReadBytes())
 	{
 		assert(m_NUM <= 4);
-		stream.Read(&m_R[4 - m_NUM], 4);
+		stream.ReadValue<4>(&m_R[4 - m_NUM]);
 		m_NUM--;
 	}
 
@@ -662,7 +662,7 @@ void CVif::Cmd_STCOL(StreamType& stream, CODE nCommand)
 	while(m_NUM != 0 && stream.GetAvailableReadBytes())
 	{
 		assert(m_NUM <= 4);
-		stream.Read(&m_C[4 - m_NUM], 4);
+		stream.ReadValue<4>(&m_C[4 - m_NUM]);
 		m_NUM--;
 	}
 
@@ -680,7 +680,7 @@ void CVif::Cmd_STMASK(StreamType& stream, CODE command)
 {
 	while(m_NUM != 0 && stream.GetAvailableReadBytes())
 	{
-		stream.Read(&m_MASK, 4);
+		stream.ReadValue<4>(&m_MASK);
 		m_NUM--;
 	}
 
@@ -711,12 +711,10 @@ void CVif::Cmd_UNPACK(StreamType& stream, CODE nCommand, uint32 nDstAddr)
 	((*this).*(unpackFct))(stream, nCommand, nDstAddr);
 }
 
-uint32 CVif::GetMaskOp(unsigned int row, unsigned int col) const
+uint32 CVif::GetColMaskOp(unsigned int col) const
 {
-	if(col > 3) col = 3;
-	assert(row < 4);
-	unsigned int index = (col * 4) + row;
-	return (m_MASK >> (index * 2)) & 0x03;
+	assert(col < 4);
+	return (m_MASK >> (col * 8)) & 0xFF;
 }
 
 void CVif::PrepareMicroProgram()
@@ -726,7 +724,7 @@ void CVif::PrepareMicroProgram()
 
 void CVif::StartMicroProgram(uint32 address)
 {
-	if(m_vpu.IsVuRunning())
+	if(!m_vpu.IsVuReady())
 	{
 		m_STAT.nVEW = 1;
 		return;
@@ -742,7 +740,7 @@ void CVif::StartDelayedMicroProgram(uint32 address)
 	//Snowblind Studio games start a VU microprogram and issues an UNPACK command
 	//which has data needed by the microprogram. We simulate the microprogram
 	//starting a bit later to let the UNPACK command execute
-	if(m_vpu.IsVuRunning())
+	if(!m_vpu.IsVuReady())
 	{
 		m_STAT.nVEW = 1;
 		return;
@@ -758,7 +756,7 @@ bool CVif::ResumeDelayedMicroProgram()
 	if(m_pendingMicroProgram != -1)
 	{
 		assert(!IsWaitingForProgramEnd());
-		assert(!m_vpu.IsVuRunning());
+		assert(m_vpu.IsVuReady());
 		m_vpu.ExecuteMicroProgram(m_pendingMicroProgram);
 		m_pendingMicroProgram = -1;
 		return true;
