@@ -14,8 +14,16 @@ public:
 protected:
 	typedef std::pair<uint128, uint32> CachedBlockKey;
 	typedef std::multimap<CachedBlockKey, BasicBlockPtr> CachedBlockMap;
-	CachedBlockMap m_cachedBlocks;
+
+	struct BLOCK_COMPILE_HINTS
+	{
+		CachedBlockKey blockKey;
+		uint32 hints;
+	};
 
 	BasicBlockPtr BlockFactory(CMIPS&, uint32, uint32) override;
 	void PartitionFunction(uint32) override;
+
+	static const BLOCK_COMPILE_HINTS g_blockCompileHints[];
+	CachedBlockMap m_cachedBlocks;
 };
