@@ -1266,6 +1266,8 @@ unsigned int CGSHandler::GetCrtWidth() const
 	case CRT_MODE_PAL:
 	case CRT_MODE_VGA_640_75:
 		return 640;
+	case CRT_MODE_HDTV_480P:
+		return 720;
 	}
 }
 
@@ -1281,6 +1283,7 @@ unsigned int CGSHandler::GetCrtHeight() const
 	case CRT_MODE_PAL:
 		return 512;
 	case CRT_MODE_VGA_640_75:
+	case CRT_MODE_HDTV_480P:
 		return 480;
 	}
 }
@@ -1293,6 +1296,7 @@ uint32 CGSHandler::GetCrtFrameRate() const
 		assert(false);
 		[[fallthrough]];
 	case CRT_MODE_NTSC:
+	case CRT_MODE_HDTV_480P:
 		return 60;
 	case CRT_MODE_PAL:
 		return 50;
@@ -1310,6 +1314,8 @@ uint32 CGSHandler::GetCrtHSyncFrequency() const
 		return PS2::GS_NTSC_HSYNC_FREQ;
 	case CRT_MODE_PAL:
 		return PS2::GS_PAL_HSYNC_FREQ;
+	case CRT_MODE_HDTV_480P:
+		return PS2::GS_HDTV_480P_HSYNC_FREQ;
 	}
 }
 
