@@ -4,7 +4,7 @@
 #include "../Ps2Const.h"
 #include "../COP_SCU.h"
 #include "../ee/SIF.h"
-#include "../Log.h"
+#include "Log.h"
 #include "../states/RegisterStateCollectionFile.h"
 
 using namespace Iop;
@@ -78,7 +78,10 @@ CSifCmd::~CSifCmd()
 
 void CSifCmd::LoadState(Framework::CZipArchiveReader& archive)
 {
-	ClearServers();
+	//We must not have any servers here. Otherwise, make sure we've cleared them up
+	//in CIopBios::PreLoadState since the info pointed in by the server data relies
+	//on RAM before state load.
+	assert(m_servers.empty());
 
 	auto modulesFile = CRegisterStateCollectionFile(*archive.BeginReadFile(STATE_MODULES));
 	{
@@ -87,9 +90,9 @@ void CSifCmd::LoadState(Framework::CZipArchiveReader& archive)
 			const auto& moduleState(moduleStatePair.second);
 			uint32 serverDataAddress = moduleState.GetRegister32(STATE_MODULE_SERVER_DATA_ADDRESS);
 			auto serverData = reinterpret_cast<SIFRPCSERVERDATA*>(m_ram + serverDataAddress);
-			auto module = new CSifDynamic(*this, serverDataAddress);
-			m_servers.push_back(module);
-			m_sifMan.RegisterModule(serverData->serverId, module);
+			auto module = std::make_unique<CSifDynamic>(*this, serverDataAddress);
+			m_sifMan.RegisterModule(serverData->serverId, module.get());
+			m_servers.push_back(std::move(module));
 		}
 	}
 }
@@ -339,7 +342,6 @@ void CSifCmd::ClearServers()
 	{
 		auto serverData = reinterpret_cast<SIFRPCSERVERDATA*>(m_ram + server->GetServerDataAddress());
 		m_sifMan.UnregisterModule(serverData->serverId);
-		delete server;
 	}
 	m_servers.clear();
 }
@@ -833,12 +835,12 @@ uint32 CSifCmd::SifSendCmd(uint32 commandId, uint32 packetPtr, uint32 packetSize
 		dmaReg->size = sizeExtra;
 		dmaReg->flags = 0;
 
-		m_sifMan.SifSetDma(m_sendCmdExtraStructAddr, 1);
+		m_sifMan.ExecuteSifDma(m_sendCmdExtraStructAddr, 1);
 	}
 
 	m_sifMan.SendPacket(packetData, packetSize);
 
-	return 1;
+	return CSifMan::SIFDMA_XFER_ID;
 }
 
 void CSifCmd::SifBindRpc(CMIPS& context)
@@ -902,7 +904,7 @@ void CSifCmd::SifCallRpc(CMIPS& context)
 		dmaReg->size = sendSize;
 		dmaReg->flags = 0;
 
-		m_sifMan.SifSetDma(m_sendCmdExtraStructAddr, 1);
+		m_sifMan.ExecuteSifDma(m_sendCmdExtraStructAddr, 1);
 	}
 
 	SIFRPCCALL callPacket;
@@ -940,13 +942,23 @@ void CSifCmd::SifRegisterRpc(CMIPS& context)
 	bool moduleRegistered = m_sifMan.IsModuleRegistered(serverId);
 	if(!moduleRegistered)
 	{
-		auto module = new CSifDynamic(*this, serverDataAddr);
-		m_servers.push_back(module);
-		m_sifMan.RegisterModule(serverId, module);
+		auto module = std::make_unique<CSifDynamic>(*this, serverDataAddr);
+		m_sifMan.RegisterModule(serverId, module.get());
+		m_servers.push_back(std::move(module));
 	}
 
 	if(serverDataAddr != 0)
 	{
+		if(buffer == 0)
+		{
+			//This is needed by Pia Carrot e Yokoso: GO Summer Fair.
+			//Game passes 0 for buffer and we have a check in ProcessInvocation to prevent copying RPC call
+			//parameters to address 0. On a real PS2, it probably doesn't really matter, but this is a
+			//questionable thing to do, so, let's be safe and allocate some buffer for the game.
+			CLog::GetInstance().Warn(LOG_NAME, "SifRegisterRpc: address 0 provided for RPC server buffer, allocating dummy buffer.\r\n");
+			buffer = m_sysMem.AllocateMemory(0x100, 0, 0);
+		}
+
 		auto serverData = reinterpret_cast<SIFRPCSERVERDATA*>(&m_ram[serverDataAddr]);
 		serverData->serverId = serverId;
 		serverData->function = function;
@@ -1056,7 +1068,14 @@ uint32 CSifCmd::SifRemoveRpc(uint32 serverDataAddr, uint32 queueDataAddr)
 		return 0;
 	}
 
+	auto matchPredicate =
+	    [serverDataAddr](const DynamicModulePtr& module) {
+		    return module->GetServerDataAddress() == serverDataAddr;
+	    };
+
 	m_sifMan.UnregisterModule(serverData->serverId);
+	assert(std::count_if(std::begin(m_servers), std::end(m_servers), matchPredicate) == 1);
+	m_servers.erase(std::remove_if(std::begin(m_servers), std::end(m_servers), matchPredicate), std::end(m_servers));
 
 	return 1;
 }
