@@ -11,13 +11,16 @@ namespace Iop
 	class CSifMan : public CModule
 	{
 	public:
+		static constexpr uint32 SIFDMA_XFER_ID = 0x2222;
+
 		typedef std::function<void(const std::string&)> ModuleResetHandler;
 		typedef std::function<void(uint32)> CustomCommandHandler;
 
-		CSifMan();
+		CSifMan() = default;
 		virtual ~CSifMan() = default;
 
-		void GenerateHandlers(uint8*, CSysmem&);
+		void PrepareModuleData(uint8*, CSysmem&);
+		void CountTicks(int32);
 
 		std::string GetId() const override;
 		std::string GetFunctionName(unsigned int) const override;
@@ -33,15 +36,30 @@ namespace Iop
 		virtual void GetOtherData(uint32, uint32, uint32) = 0;
 		virtual void SetModuleResetHandler(const ModuleResetHandler&) = 0;
 		virtual void SetCustomCommandHandler(const CustomCommandHandler&) = 0;
+		virtual void ExecuteSifDma(uint32, uint32) = 0;
 
-		virtual uint32 SifSetDma(uint32, uint32);
-
-	protected:
-		virtual uint32 SifDmaStat(uint32);
+	private:
+		uint32 SifSetDma(uint32, uint32);
+		uint32 SifDmaStat(uint32);
 		uint32 SifCheckInit();
-		virtual uint32 SifSetDmaCallback(CMIPS&, uint32, uint32, uint32, uint32);
+		uint32 SifSetDmaCallback(CMIPS&, uint32, uint32, uint32, uint32);
 
-		uint32 m_sifSetDmaCallbackHandlerPtr;
+		enum
+		{
+			SIFSETDMACALLBACK_HANDLER_SIZE = 0x28,
+			DMA_TRANSFER_TIMES_SIZE = 5,
+		};
+
+		struct MODULEDATA
+		{
+			uint8 sifSetDmaCallbackHandler[SIFSETDMACALLBACK_HANDLER_SIZE];
+			int32 dmaTransferTimes[DMA_TRANSFER_TIMES_SIZE];
+			int32 nextDmaTransferIdx;
+		};
+		static_assert(sizeof(MODULEDATA) == 0x40);
+
+		MODULEDATA* m_moduleData = nullptr;
+		uint32 m_sifSetDmaCallbackHandlerAddr = 0;
 	};
 
 	typedef std::shared_ptr<CSifMan> SifManPtr;
