@@ -1,7 +1,7 @@
 #include <cstring>
 #include "Iop_Sysclib.h"
 #include "../Ps2Const.h"
-#include "../Log.h"
+#include "Log.h"
 
 #define LOG_NAME "iop_sysclib"
 
