@@ -4,6 +4,7 @@
 
 using namespace Jitter;
 
+// clang-format off
 CX86Assembler::REGISTER CCodeGen_x86_64::g_systemVRegisters[SYSTEMV_MAX_REGISTERS] =
 {
 	CX86Assembler::rBX,
@@ -58,11 +59,7 @@ CX86Assembler::XMMREGISTER CCodeGen_x86_64::g_mdRegisters[MAX_MDREGISTERS] =
 	CX86Assembler::xMM14,
 	CX86Assembler::xMM15
 };
-
-static uint64 CombineConstant64(uint32 cstLow, uint32 cstHigh)
-{
-	return (static_cast<uint64>(cstHigh) << 32) | static_cast<uint64>(cstLow);
-}
+// clang-format on
 
 //ALUOP
 //-------------------------------------------------------------------
@@ -91,7 +88,7 @@ void CCodeGen_x86_64::Emit_Alu64_MemMemCst(const STATEMENT& statement)
 	assert(src2->m_type == SYM_CONSTANT64);
 
 	CX86Assembler::REGISTER tmpReg = CX86Assembler::rAX;
-	uint64 constant = CombineConstant64(src2->m_valueLow, src2->m_valueHigh);
+	uint64 constant = src2->GetConstant64();
 
 	m_assembler.MovEq(tmpReg, MakeMemory64SymbolAddress(src1));
 	if(CX86Assembler::GetMinimumConstantSize64(constant) >= 4)
@@ -117,17 +114,19 @@ void CCodeGen_x86_64::Emit_Alu64_MemCstMem(const STATEMENT& statement)
 	assert(src1->m_type == SYM_CONSTANT64);
 
 	CX86Assembler::REGISTER tmpReg = CX86Assembler::rAX;
-	uint64 constant = CombineConstant64(src1->m_valueLow, src1->m_valueHigh);
+	uint64 constant = src1->GetConstant64();
 
 	m_assembler.MovIq(tmpReg, constant);
 	((m_assembler).*(ALUOP::OpEq()))(tmpReg, MakeMemory64SymbolAddress(src2));
 	m_assembler.MovGq(MakeMemory64SymbolAddress(dst), tmpReg);
 }
 
+// clang-format off
 #define ALU64_CONST_MATCHERS(ALUOP_CST, ALUOP) \
 	{ ALUOP_CST, MATCH_MEMORY64, MATCH_MEMORY64,   MATCH_MEMORY64,   MATCH_NIL, &CCodeGen_x86_64::Emit_Alu64_MemMemMem<ALUOP> }, \
 	{ ALUOP_CST, MATCH_MEMORY64, MATCH_MEMORY64,   MATCH_CONSTANT64, MATCH_NIL, &CCodeGen_x86_64::Emit_Alu64_MemMemCst<ALUOP> }, \
 	{ ALUOP_CST, MATCH_MEMORY64, MATCH_CONSTANT64, MATCH_MEMORY64,   MATCH_NIL, &CCodeGen_x86_64::Emit_Alu64_MemCstMem<ALUOP> },
+// clang-format on
 
 //SHIFTOP
 //-------------------------------------------------------------------
@@ -139,7 +138,7 @@ void CCodeGen_x86_64::Emit_Shift64_RelRelReg(const STATEMENT& statement)
 	CSymbol* src1 = statement.src1->GetSymbol().get();
 	CSymbol* src2 = statement.src2->GetSymbol().get();
 
-	assert(dst->m_type  == SYM_RELATIVE64);
+	assert(dst->m_type == SYM_RELATIVE64);
 	assert(src1->m_type == SYM_RELATIVE64);
 	assert(src2->m_type == SYM_REGISTER);
 
@@ -159,7 +158,7 @@ void CCodeGen_x86_64::Emit_Shift64_RelRelMem(const STATEMENT& statement)
 	CSymbol* src1 = statement.src1->GetSymbol().get();
 	CSymbol* src2 = statement.src2->GetSymbol().get();
 
-	assert(dst->m_type  == SYM_RELATIVE64);
+	assert(dst->m_type == SYM_RELATIVE64);
 	assert(src1->m_type == SYM_RELATIVE64);
 
 	CX86Assembler::REGISTER tmpReg = CX86Assembler::rAX;
@@ -178,7 +177,7 @@ void CCodeGen_x86_64::Emit_Shift64_RelRelCst(const STATEMENT& statement)
 	CSymbol* src1 = statement.src1->GetSymbol().get();
 	CSymbol* src2 = statement.src2->GetSymbol().get();
 
-	assert(dst->m_type  == SYM_RELATIVE64);
+	assert(dst->m_type == SYM_RELATIVE64);
 	assert(src1->m_type == SYM_RELATIVE64);
 	assert(src2->m_type == SYM_CONSTANT);
 
@@ -189,6 +188,7 @@ void CCodeGen_x86_64::Emit_Shift64_RelRelCst(const STATEMENT& statement)
 	m_assembler.MovGq(MakeRelative64SymbolAddress(dst), tmpReg);
 }
 
+// clang-format off
 #define SHIFT64_CONST_MATCHERS(SHIFTOP_CST, SHIFTOP) \
 	{ SHIFTOP_CST, MATCH_RELATIVE64, MATCH_RELATIVE64, MATCH_REGISTER, MATCH_NIL, &CCodeGen_x86_64::Emit_Shift64_RelRelReg<SHIFTOP> }, \
 	{ SHIFTOP_CST, MATCH_RELATIVE64, MATCH_RELATIVE64, MATCH_MEMORY,   MATCH_NIL, &CCodeGen_x86_64::Emit_Shift64_RelRelMem<SHIFTOP> }, \
@@ -264,6 +264,7 @@ CCodeGen_x86_64::CONSTMATCHER CCodeGen_x86_64::g_constMatchers[] =
 
 	{ OP_MOV, MATCH_NIL, MATCH_NIL, MATCH_NIL, MATCH_NIL, nullptr },
 };
+// clang-format on
 
 CCodeGen_x86_64::CCodeGen_x86_64(CX86CpuFeatures features)
     : CCodeGen_x86(features)
@@ -274,12 +275,12 @@ CCodeGen_x86_64::CCodeGen_x86_64(CX86CpuFeatures features)
 	for(CONSTMATCHER* constMatcher = g_constMatchers; constMatcher->emitter != NULL; constMatcher++)
 	{
 		MATCHER matcher;
-		matcher.op       = constMatcher->op;
-		matcher.dstType  = constMatcher->dstType;
+		matcher.op = constMatcher->op;
+		matcher.dstType = constMatcher->dstType;
 		matcher.src1Type = constMatcher->src1Type;
 		matcher.src2Type = constMatcher->src2Type;
 		matcher.src3Type = constMatcher->src3Type;
-		matcher.emitter  = std::bind(constMatcher->emitter, this, std::placeholders::_1);
+		matcher.emitter = std::bind(constMatcher->emitter, this, std::placeholders::_1);
 		m_matchers.insert(MatcherMapType::value_type(matcher.op, matcher));
 	}
 }
@@ -290,18 +291,18 @@ void CCodeGen_x86_64::SetPlatformAbi(PLATFORM_ABI platformAbi)
 	switch(m_platformAbi)
 	{
 	case PLATFORM_ABI_SYSTEMV:
-		CCodeGen_x86::m_registers    = g_systemVRegisters;
-		m_paramRegs                  = g_systemVParamRegs;
-		m_maxRegisters               = SYSTEMV_MAX_REGISTERS;
-		m_maxParams                  = SYSTEMV_MAX_PARAMS;
-		m_hasMdRegRetValues          = true;
+		CCodeGen_x86::m_registers = g_systemVRegisters;
+		m_paramRegs = g_systemVParamRegs;
+		m_maxRegisters = SYSTEMV_MAX_REGISTERS;
+		m_maxParams = SYSTEMV_MAX_PARAMS;
+		m_hasMdRegRetValues = true;
 		break;
 	case PLATFORM_ABI_WIN32:
-		CCodeGen_x86::m_registers    = g_win32Registers;
-		m_paramRegs                  = g_win32ParamRegs;
-		m_maxRegisters               = WIN32_MAX_REGISTERS;
-		m_maxParams                  = WIN32_MAX_PARAMS;
-		m_hasMdRegRetValues          = false;
+		CCodeGen_x86::m_registers = g_win32Registers;
+		m_paramRegs = g_win32ParamRegs;
+		m_maxRegisters = WIN32_MAX_REGISTERS;
+		m_maxParams = WIN32_MAX_PARAMS;
+		m_hasMdRegRetValues = false;
 		break;
 	default:
 		throw std::runtime_error("Unsupported ABI.");
@@ -343,18 +344,18 @@ void CCodeGen_x86_64::Emit_Prolog(const StatementList& statements, unsigned int
 			{
 			case OP_PARAM:
 			case OP_PARAM_RET:
+			{
+				CSymbol* src1 = statement.src1->GetSymbol().get();
+				switch(src1->m_type)
 				{
-					CSymbol* src1 = statement.src1->GetSymbol().get();
-					switch(src1->m_type)
-					{
-					case SYM_REGISTER128:
-						currParamSpillSize += 16;
-						break;
-					default:
-						break;
-					}
+				case SYM_REGISTER128:
+					currParamSpillSize += 16;
+					break;
+				default:
+					break;
 				}
-				break;
+			}
+			break;
 			case OP_CALL:
 				maxParamSpillSize = std::max<uint32>(currParamSpillSize, maxParamSpillSize);
 				currParamSpillSize = 0;
@@ -364,7 +365,7 @@ void CCodeGen_x86_64::Emit_Prolog(const StatementList& statements, unsigned int
 			}
 		}
 	}
-	
+
 	assert((maxParamSpillSize & 0x0F) == 0);
 	assert((stackSize & 0x0F) == 0);
 
@@ -433,12 +434,10 @@ void CCodeGen_x86_64::Emit_Param_Ctx(const STATEMENT& statement)
 	assert(m_params.size() < m_maxParams);
 
 	m_params.push_back(
-		[this] (CX86Assembler::REGISTER paramReg, uint32)
-		{
-			m_assembler.MovEq(paramReg, CX86Assembler::MakeRegisterAddress(CX86Assembler::rBP));
-			return 0;
-		}
-	);
+	    [this](CX86Assembler::REGISTER paramReg, uint32) {
+		    m_assembler.MovEq(paramReg, CX86Assembler::MakeRegisterAddress(CX86Assembler::rBP));
+		    return 0;
+	    });
 }
 
 void CCodeGen_x86_64::Emit_Param_Reg(const STATEMENT& statement)
@@ -448,12 +447,10 @@ void CCodeGen_x86_64::Emit_Param_Reg(const STATEMENT& statement)
 	auto src1 = statement.src1->GetSymbol().get();
 
 	m_params.push_back(
-		[this, src1] (CX86Assembler::REGISTER paramReg, uint32)
-		{
-			m_assembler.MovEd(paramReg, CX86Assembler::MakeRegisterAddress(m_registers[src1->m_valueLow]));
-			return 0;
-		}
-	);
+	    [this, src1](CX86Assembler::REGISTER paramReg, uint32) {
+		    m_assembler.MovEd(paramReg, CX86Assembler::MakeRegisterAddress(m_registers[src1->m_valueLow]));
+		    return 0;
+	    });
 }
 
 void CCodeGen_x86_64::Emit_Param_Mem(const STATEMENT& statement)
@@ -463,12 +460,10 @@ void CCodeGen_x86_64::Emit_Param_Mem(const STATEMENT& statement)
 	auto src1 = statement.src1->GetSymbol().get();
 
 	m_params.push_back(
-		[this, src1] (CX86Assembler::REGISTER paramReg, uint32)
-		{
-			m_assembler.MovEd(paramReg, MakeMemorySymbolAddress(src1));
-			return 0;
-		}
-	);
+	    [this, src1](CX86Assembler::REGISTER paramReg, uint32) {
+		    m_assembler.MovEd(paramReg, MakeMemorySymbolAddress(src1));
+		    return 0;
+	    });
 }
 
 void CCodeGen_x86_64::Emit_Param_Cst(const STATEMENT& statement)
@@ -478,12 +473,10 @@ void CCodeGen_x86_64::Emit_Param_Cst(const STATEMENT& statement)
 	auto src1 = statement.src1->GetSymbol().get();
 
 	m_params.push_back(
-		[this, src1] (CX86Assembler::REGISTER paramReg, uint32)
-		{
-			m_assembler.MovId(paramReg, src1->m_valueLow);
-			return 0;
-		}
-	);
+	    [this, src1](CX86Assembler::REGISTER paramReg, uint32) {
+		    m_assembler.MovId(paramReg, src1->m_valueLow);
+		    return 0;
+	    });
 }
 
 void CCodeGen_x86_64::Emit_Param_Mem64(const STATEMENT& statement)
@@ -493,12 +486,10 @@ void CCodeGen_x86_64::Emit_Param_Mem64(const STATEMENT& statement)
 	auto src1 = statement.src1->GetSymbol().get();
 
 	m_params.push_back(
-		[this, src1] (CX86Assembler::REGISTER paramReg, uint32)
-		{
-			m_assembler.MovEq(paramReg, MakeMemory64SymbolAddress(src1));
-			return 0;
-		}
-	);
+	    [this, src1](CX86Assembler::REGISTER paramReg, uint32) {
+		    m_assembler.MovEq(paramReg, MakeMemory64SymbolAddress(src1));
+		    return 0;
+	    });
 }
 
 void CCodeGen_x86_64::Emit_Param_Cst64(const STATEMENT& statement)
@@ -508,12 +499,10 @@ void CCodeGen_x86_64::Emit_Param_Cst64(const STATEMENT& statement)
 	auto src1 = statement.src1->GetSymbol().get();
 
 	m_params.push_back(
-		[this, src1] (CX86Assembler::REGISTER paramReg, uint32)
-		{
-			m_assembler.MovIq(paramReg, CombineConstant64(src1->m_valueLow, src1->m_valueHigh));
-			return 0;
-		}
-	);
+	    [this, src1](CX86Assembler::REGISTER paramReg, uint32) {
+		    m_assembler.MovIq(paramReg, src1->GetConstant64());
+		    return 0;
+	    });
 }
 
 void CCodeGen_x86_64::Emit_Param_Reg128(const STATEMENT& statement)
@@ -523,14 +512,12 @@ void CCodeGen_x86_64::Emit_Param_Reg128(const STATEMENT& statement)
 	auto src1 = statement.src1->GetSymbol().get();
 
 	m_params.push_back(
-		[this, src1] (CX86Assembler::REGISTER paramReg, uint32 paramSpillOffset)
-		{
-			auto paramTempAddr = CX86Assembler::MakeIndRegOffAddress(CX86Assembler::rSP, m_paramSpillBase + paramSpillOffset);
-			m_assembler.MovapsVo(paramTempAddr, m_mdRegisters[src1->m_valueLow]);
-			m_assembler.LeaGq(paramReg, paramTempAddr);
-			return 0x10;
-		}
-	);
+	    [this, src1](CX86Assembler::REGISTER paramReg, uint32 paramSpillOffset) {
+		    auto paramTempAddr = CX86Assembler::MakeIndRegOffAddress(CX86Assembler::rSP, m_paramSpillBase + paramSpillOffset);
+		    m_assembler.MovapsVo(paramTempAddr, m_mdRegisters[src1->m_valueLow]);
+		    m_assembler.LeaGq(paramReg, paramTempAddr);
+		    return 0x10;
+	    });
 }
 
 void CCodeGen_x86_64::Emit_Param_Mem128(const STATEMENT& statement)
@@ -540,12 +527,10 @@ void CCodeGen_x86_64::Emit_Param_Mem128(const STATEMENT& statement)
 	auto src1 = statement.src1->GetSymbol().get();
 
 	m_params.push_back(
-		[this, src1] (CX86Assembler::REGISTER paramReg, uint32)
-		{
-			m_assembler.LeaGq(paramReg, MakeMemory128SymbolAddress(src1));
-			return 0;
-		}
-	);
+	    [this, src1](CX86Assembler::REGISTER paramReg, uint32) {
+		    m_assembler.LeaGq(paramReg, MakeMemory128SymbolAddress(src1));
+		    return 0;
+	    });
 }
 
 void CCodeGen_x86_64::Emit_Call(const STATEMENT& statement)
@@ -563,7 +548,7 @@ void CCodeGen_x86_64::Emit_Call(const STATEMENT& statement)
 		paramSpillOffset += emitter(m_paramRegs[i], paramSpillOffset);
 	}
 
-	m_assembler.MovIq(CX86Assembler::rAX, CombineConstant64(src1->m_valueLow, src1->m_valueHigh));
+	m_assembler.MovIq(CX86Assembler::rAX, src1->GetConstantPtr());
 	auto symbolRefLabel = m_assembler.CreateLabel();
 	m_assembler.MarkLabel(symbolRefLabel, -8);
 	m_symbolReferenceLabels.push_back(std::make_pair(src1->GetConstantPtr(), symbolRefLabel));
@@ -594,7 +579,7 @@ void CCodeGen_x86_64::Emit_RetVal_Mem64(const STATEMENT& statement)
 void CCodeGen_x86_64::Emit_RetVal_Reg128(const STATEMENT& statement)
 {
 	auto dst = statement.dst->GetSymbol().get();
-	
+
 	//TODO: Use only integer operations
 	m_assembler.MovqVo(m_mdRegisters[dst->m_valueLow], CX86Assembler::MakeRegisterAddress(CX86Assembler::rAX));
 	m_assembler.MovqVo(CX86Assembler::xMM0, CX86Assembler::MakeRegisterAddress(CX86Assembler::rDX));
@@ -611,10 +596,10 @@ void CCodeGen_x86_64::Emit_RetVal_Mem128(const STATEMENT& statement)
 void CCodeGen_x86_64::Emit_ExternJmp(const STATEMENT& statement)
 {
 	auto src1 = statement.src1->GetSymbol().get();
-	
+
 	m_assembler.MovEq(m_paramRegs[0], CX86Assembler::MakeRegisterAddress(g_baseRegister));
 	Emit_Epilog();
-	m_assembler.MovIq(CX86Assembler::rAX, CombineConstant64(src1->m_valueLow, src1->m_valueHigh));
+	m_assembler.MovIq(CX86Assembler::rAX, src1->GetConstantPtr());
 	auto symbolRefLabel = m_assembler.CreateLabel();
 	m_assembler.MarkLabel(symbolRefLabel, -8);
 	m_symbolReferenceLabels.push_back(std::make_pair(src1->GetConstantPtr(), symbolRefLabel));
@@ -716,7 +701,7 @@ void CCodeGen_x86_64::Emit_Cmp64_VarMemCst(const STATEMENT& statement)
 	assert(src2->m_type == SYM_CONSTANT64);
 
 	auto dstReg = PrepareSymbolRegisterDef(dst, CX86Assembler::rAX);
-	uint64 constant = CombineConstant64(src2->m_valueLow, src2->m_valueHigh);
+	uint64 constant = src2->GetConstant64();
 
 	m_assembler.XorEd(dstReg, CX86Assembler::MakeRegisterAddress(dstReg));
 
@@ -764,7 +749,7 @@ void CCodeGen_x86_64::Emit_AddRef_VarVarVar(const STATEMENT& statement)
 	auto offsetReg = PrepareSymbolRegisterUse(src2, CX86Assembler::rCX);
 	auto dstReg = PrepareRefSymbolRegisterDef(dst, CX86Assembler::rAX);
 
-	if(!dst->Equals(src1))
+	if(!(dst->IsRegister() && dst->Equals(src1)))
 	{
 		m_assembler.MovEq(dstReg, MakeVariableReferenceSymbolAddress(src1));
 	}
@@ -783,7 +768,7 @@ void CCodeGen_x86_64::Emit_AddRef_VarVarCst(const STATEMENT& statement)
 
 	auto dstReg = PrepareRefSymbolRegisterDef(dst, CX86Assembler::rAX);
 
-	if(!dst->Equals(src1))
+	if(!(dst->IsRegister() && dst->Equals(src1)))
 	{
 		m_assembler.MovEq(dstReg, MakeVariableReferenceSymbolAddress(src1));
 	}
@@ -903,8 +888,8 @@ void CCodeGen_x86_64::Emit_StoreAtRef_64_VarAnyCst(const STATEMENT& statement)
 
 	assert((scale == 1) || (scale == 8));
 
-	WriteConstant64ToAddress(MakeRefBaseScaleSymbolAddress(src1, CX86Assembler::rAX, src2, CX86Assembler::rCX, scale), 
-		CX86Assembler::rDX, src3->GetConstant64());
+	WriteConstant64ToAddress(MakeRefBaseScaleSymbolAddress(src1, CX86Assembler::rAX, src2, CX86Assembler::rCX, scale),
+	                         CX86Assembler::rDX, src3->GetConstant64());
 }
 
 void CCodeGen_x86_64::Emit_Store8AtRef_VarVar(const STATEMENT& statement)
