@@ -1,6 +1,6 @@
 #pragma once
 
-#ifdef _MSC_VER
+#if defined(_MSC_VER) && defined(__cpp_lib_experimental_erase_if)
 
 #include <experimental/map>
 
